@@ -1,4 +1,5 @@
 import base64
+import importlib.metadata as lib_meta
 import mimetypes
 from contextlib import suppress
 from importlib import import_module
@@ -6,6 +7,8 @@ from pathlib import Path
 
 from .toucan_connector import DataSlice, ToucanConnector, ToucanDataSource
 
+__version__ = lib_meta.version(__package__ or __name__)
+
 CONNECTORS_REGISTRY = {
     'AdobeAnalytics': {
         'connector': 'adobe_analytics.adobe_analytics_connector.AdobeAnalyticsConnector',
@@ -16,6 +19,11 @@ CONNECTORS_REGISTRY = {
         'connector': 'aircall.aircall_connector.AircallConnector',
         'logo': 'aircall/Aircall.svg',
     },
+    'Anaplan': {
+        'connector': 'anaplan.anaplan_connector.AnaplanConnector',
+        'label': 'Anaplan',
+        'logo': 'anaplan/anaplan.png',
+    },
     'AWSAthena': {
         'connector': 'awsathena.awsathena_connector.AwsathenaConnector',
         'label': 'Amazon Athena',
@@ -129,6 +137,11 @@ CONNECTORS_REGISTRY = {
         'label': 'Hubspot',
         'logo': 'hubspot/hubspot.png',
     },
+    'HubspotPrivateApp': {
+        'connector': 'hubspot_private_app.hubspot_connector.HubspotConnector',
+        'label': 'Hubspot (Private App)',
+        'logo': 'hubspot/hubspot.png',
+    },
     'Indexima': {
         'connector': 'hive.hive_connector.HiveConnector',
         'logo': 'hive/indexima.png',
