@@ -1,5 +1,5 @@
 from functools import _lru_cache_wrapper, lru_cache
-from typing import Optional, Pattern, Union
+from typing import Any, List, Optional, Pattern, Union
 
 import pandas as pd
 import pymongo
@@ -15,6 +15,8 @@ from toucan_connectors.toucan_connector import (
     DataStats,
     ToucanConnector,
     ToucanDataSource,
+    UnavailableVersion,
+    VersionableEngineConnector,
     decorate_func_with_retry,
     strlist_to_enum,
 )
@@ -22,9 +24,45 @@ from toucan_connectors.toucan_connector import (
 MAX_COUNTED_ROWS = 1000001
 
 
+def _is_match_empty(match_: dict) -> bool:
+    def is_empty(elem: Any):
+        # Not matching None here, because we don't want to consider {'$match': {'col': None}} to be
+        # empty
+        if elem == {}:
+            return True
+        if isinstance(elem, dict):
+            return _is_match_empty(elem)
+        return False
+
+    return all(is_empty(v) for v in match_.values())
+
+
+def _is_match_statement(d: Any) -> bool:
+    return isinstance(d, dict) and list(d.keys()) == ['$match']
+
+
+def _sanitize_query_matches(query: dict | list[dict]) -> Any:
+    """Transforms match operations matching nothing into match-alls.
+
+    If a $match would match nothing (for example, {'$match': {'field': {}}}), transform into a
+    passthrough. It cannot be removed from the query to prevent having an empty query.
+    """
+    if isinstance(query, list):
+        return [
+            {'$match': {}} if (_is_match_statement(q) and _is_match_empty(q)) else q for q in query
+        ]
+    return query
+
+
 def normalize_query(query, parameters):
     query = nosql_apply_parameters_to_query(query, parameters)
 
+    # FIXME: This removes empty $match operations that could have been created while removing
+    # missing parameters from the query in nosql_apply_parameters to query. However, this way of
+    # handling __VOID__ filters is hacky and should be implemented earlier, when translating the VQB
+    # pipeline
+    query = _sanitize_query_matches(query)
+
     if isinstance(query, dict):
         query = [{'$match': query}]
 
@@ -89,7 +127,7 @@ class MongoDataSource(ToucanDataSource):
         return create_model('FormSchema', **constraints, __base__=cls).schema()
 
 
-class MongoConnector(ToucanConnector):
+class MongoConnector(ToucanConnector, VersionableEngineConnector):
     """Retrieve data from a [MongoDB](https://www.mongodb.com/) database."""
 
     data_source_model: MongoDataSource
@@ -223,10 +261,17 @@ class MongoConnector(ToucanConnector):
                 df_facet.append({'$skip': offset})
             if limit is not None:
                 df_facet.append({'$limit': limit})
+
+            df_facet.append({'$unset': ['_id']})
+
             facet = {
                 '$facet': {
                     # counting more than 1M values can be really slow, and the exact number is not that much relevant
-                    'count': [{'$limit': MAX_COUNTED_ROWS}, {'$count': 'value'}],
+                    'count': [
+                        {'$limit': MAX_COUNTED_ROWS},
+                        {'$count': 'value'},
+                        {'$unset': ['_id']},
+                    ],
                     'df': df_facet,  # df_facet is never empty
                 }
             }
@@ -238,18 +283,24 @@ class MongoConnector(ToucanConnector):
         else:
             df = self.get_df(data_source, permissions)
             total_count = len(df)
+            # We try to remove the _id from this DataFrame if there is one
+            # ugly for now but we need to handle that in this else case
+            try:
+                df.pop('_id')
+            except Exception:
+                pass
         return DataSlice(
             df, stats=DataStats(total_returned_rows=total_count, total_rows=total_count)
         )
 
-    def get_df_with_regex(
+    def get_slice_with_regex(
         self,
         data_source: MongoDataSource,
-        field: str,
-        regex: Pattern,
+        search: dict[str, List[dict[str, Pattern]]],
         permissions: Optional[str] = None,
         limit: Optional[int] = None,
-    ) -> pd.DataFrame:
+        offset: Optional[int] = None,
+    ) -> DataSlice:
         # Create a copy in order to keep the original (deepcopy-like)
         data_source = MongoDataSource.parse_obj(data_source)
         data_source.query = normalize_query(data_source.query, data_source.parameters)
@@ -257,17 +308,43 @@ class MongoConnector(ToucanConnector):
         # Mongo will then optimize the pipeline to move the match regex to its most convenient position
         # (c.f https://docs.mongodb.com/manual/core/aggregation-pipeline-optimization/#pipeline-sequence-optimization)
         # Since Mongo '$regex' operator doesn't work with integer values, we need to check the stringified versions
-        regex_step = {
-            '$expr': {
-                '$regexMatch': {
-                    'input': {'$toString': f'${field}'},
-                    'regex': regex.pattern,
-                    'options': 'i',  # i -> Case insensitivity
-                }
-            }
-        }
-        data_source.query.append({'$match': regex_step})
-        return self.get_slice(data_source, permissions, limit=limit).df
+        search_steps = {}
+        for condition in search:
+            search_steps[f'${condition}'] = []  # convert "and"/"or" to "$and"/"$or"
+            for column in search[condition]:
+                search_steps[f'${condition}'].append(
+                    {'$and': []}
+                )  # makes an "and" of all columns searches
+                for col, regex in column.items():
+                    search_steps[f'${condition}'][-1]['$and'].append(
+                        {
+                            '$regexMatch': {
+                                'input': {'$toString': f'${col}'},
+                                'regex': regex.pattern,
+                                'options': 'i',  # i -> Case insensitivity
+                            }
+                        }
+                    )
+        data_source.query.append({'$match': {'$expr': search_steps}})
+        data_source.query.append({'$unset': ['_id']})
+
+        return self.get_slice(data_source, permissions, limit=limit, offset=offset)
+
+    def get_df_with_regex(
+        self,
+        data_source: MongoDataSource,
+        search: dict[str, List[dict[str, Pattern]]],
+        permissions: Optional[str] = None,
+        limit: Optional[int] = None,
+        offset: Optional[int] = None,
+    ) -> pd.DataFrame:
+        return self.get_slice_with_regex(
+            data_source=data_source,
+            search=search,
+            permissions=permissions,
+            limit=limit,
+            offset=offset,
+        ).df
 
     @decorate_func_with_retry
     def explain(self, data_source, permissions=None):
@@ -300,6 +377,14 @@ class MongoConnector(ToucanConnector):
         del data_source_rendered.parameters
         return data_source_rendered.dict()
 
+    def get_engine_version(self) -> tuple:
+        client = pymongo.MongoClient(**self._get_mongo_client_kwargs())
+        try:
+            version = client.server_info()['version']
+            return super()._format_version(version)
+        except (TypeError, KeyError) as exc:
+            raise UnavailableVersion from exc
+
 
 def _format_explain_result(explain_result):
     """format output of an `explain` mongo command
