@@ -435,9 +435,13 @@ class SnowflakeConnector(ToucanConnector):
         ) as connection:
             db_contents += SnowflakeCommon().get_db_content(connection).to_dict('records')
 
-    def get_model(self):
-        with self._get_connection() as connection:
-            databases = SnowflakeCommon().get_databases(connection=connection)
+    def get_model(self, db_name: str | None = None):
+        if db_name:
+            databases = [db_name]
+        else:
+            with self._get_connection() as connection:
+                databases = SnowflakeCommon().get_databases(connection=connection)
+
         content_queries = []
         for db in databases:
             content_queries.append(build_database_model_extraction_query())
